"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ForemanLambdaFactory = void 0;
const events_1 = require("events");
const lambda_1 = require("./lambda");
class ForemanLambdaFactory extends events_1.EventEmitter {
    constructor(messageSender, tenantManager, tokenGenerator, permissions) {
        super();
        this.messageSender = messageSender;
        this.tenantManager = tenantManager;
        this.tokenGenerator = tokenGenerator;
        this.permissions = permissions;
        this.messageSender.on("error", (error) => {
            // After a message queue error we need to recreate the lambda.
            this.emit("error", error);
        });
    }
    async create(config, context) {
        return new lambda_1.ForemanLambda(this.messageSender, this.tenantManager, this.tokenGenerator, this.permissions, context, config.tenantId, config.documentId);
    }
    async dispose() {
        await this.messageSender.close();
    }
}
exports.ForemanLambdaFactory = ForemanLambdaFactory;
//# sourceMappingURL=lambdaFactory.js.map